package com.vendor.burn.model.cmdline.adapter;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.PartitionInfo;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.cmdline.CmdLineParam;
import com.vendor.burn.model.cmdline.EBurnBoot;
import com.vendor.burn.model.cmdline.adapter.BootBurn;
import com.vendor.burn.model.config.BurnConfig;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import java.io.File;
import java.util.List;
import org.dom4j.DocumentException;
import org.eclipse.osgi.util.NLS;

public class Erase extends BootBurn {
  private UnknownDevice device;
  
  private String chipName;
  
  private TransferWay mode;
  
  private String port;
  
  private FlashType flashType;
  
  private File bootFile;
  
  private File programmer;
  
  private List<String> serialPorts;
  
  private List<PartitionItem> partitionList;
  
  private String xmlPath;
  
  public boolean parseAllEarseParameter(String[] args, int paramSize, CmdLineParam cmdLineParam) {
    for (int index = 0; index < paramSize; index++) {
      String argsName = args[index];
      int parameterNumber = index + 1;
      if (argsName.equalsIgnoreCase("-n")) {
        if (!parseChipName(args, paramSize, parameterNumber)) {
          printEarseBootEg();
          return false;
        } 
      } else if (argsName.equalsIgnoreCase("-m")) {
        if (!parseMode(args, paramSize, parameterNumber)) {
          printEarseBootEg();
          return false;
        } 
        int portNumber = parameterNumber + 1;
        if (portNumber <= paramSize && args[parameterNumber].toLowerCase().contains("serial") && 
          !args[portNumber].contains("-") && 
          !parsePort(args, paramSize, portNumber)) {
          printEarseBoot();
          return false;
        } 
      } else if (argsName.equalsIgnoreCase("-p")) {
        String programmerFilePath = parseFile(args, paramSize, EBurnBoot.programmer.name(), parameterNumber);
        if (programmerFilePath != null)
          setProgrammer(new File(programmerFilePath)); 
      } else if (argsName.equalsIgnoreCase("-x")) {
        if (!parseXmlPath(args, paramSize, parameterNumber)) {
          printEarseBootEg();
          return false;
        } 
      } else if (argsName.equalsIgnoreCase("-c")) {
        if (!parseConfigPath(args, paramSize, parameterNumber, cmdLineParam)) {
          printEarseBootEg();
          return false;
        } 
      } 
    } 
    return true;
  }
  
  public boolean parseXmlPath(String[] args, int paramSize, int xmlPathNumber) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.xmlPath.name()));
      return false;
    } 
    if (paramSize >= xmlPathNumber) {
      String xmlPathStr = args[xmlPathNumber];
      if (xmlPathStr == null || xmlPathStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EBurnBoot.xmlPath.name()));
        return false;
      } 
      File file = new File(xmlPathStr);
      if (!file.exists() || !file.isFile()) {
        Log.errorln(NLS.bind(Messages.ERROR_CURRENT_XML_PATH_NOT_FOUND, EBurnBoot.xmlPath.name()));
        return false;
      } 
      setXmlPath(xmlPathStr);
      try {
        PartitionInfo partitionInfo = PartitionItem.load(file, true);
        List<PartitionItem> partitionLists = partitionInfo.getChildren();
        if (partitionLists != null && partitionLists.size() > 0) {
          setPartitionList(partitionLists);
        } else {
          Log.errorln(NLS.bind(Messages.ERROR_CURRENT_XML_PATH_NOT_FOUND, file.getCanonicalPath()));
          return false;
        } 
      } catch (DocumentException|java.io.IOException e) {
        Log.errorln(Messages.UanbleParseXml);
        return false;
      } 
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.xmlPath.name()));
    return false;
  }
  
  public boolean parseMode(String[] args, int paramSize, int modeNumber) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.mode.name()));
      printModeOptions();
      return false;
    } 
    if (paramSize >= modeNumber) {
      String modeStr = args[modeNumber];
      if (modeStr == null || modeStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EBurnBoot.mode.name()));
        printModeOptions();
        return false;
      } 
      if (modeStr.equalsIgnoreCase(EMode.serial.name())) {
        setMode(TransferWay.Serial);
      } else if (modeStr.equalsIgnoreCase(EMode.USBBootrom.name())) {
        setMode(TransferWay.USBBootrom);
      } else {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_Invalid, EBurnBoot.mode.name()));
        printModeOptions();
        return false;
      } 
      BurnConfig.setTransferway(getMode());
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.mode.name()));
    printModeOptions();
    return false;
  }
  
  public boolean parseConfigPath(String[] args, int paramSize, int configPathNumber, CmdLineParam cmdLineParam) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.configPath.name()));
      return false;
    } 
    if (paramSize >= configPathNumber) {
      String configPathStr = args[configPathNumber];
      if (configPathStr == null || configPathStr.isEmpty()) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EBurnBoot.configPath.name()));
        return false;
      } 
      File file = new File(configPathStr);
      if (!file.exists() || !file.isFile()) {
        Log.errorln(NLS.bind(Messages.ERROR_CURRENT_XML_PATH_NOT_FOUND, configPathStr));
        return false;
      } 
      cmdLineParam.setBurnConfigPath(configPathStr);
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EBurnBoot.configPath.name()));
    return false;
  }
  
  private void printModeOptions() {
    Log.println("mode:");
    EMode[] eModes = EMode.values();
    for (EMode eMode : eModes)
      Log.println(eMode.name()); 
  }
  
  private void printPortOption() {
    Log.println("input port:");
    if (this.serialPorts != null && this.serialPorts.size() > 0)
      for (String serialPort : this.serialPorts)
        Log.println(serialPort);  
  }
  
  private void printProgrammerOption() {
    Log.println("input programmer file:(options)");
  }
  
  public static void printEarseBootEg() {
    Log.println("burntoolcli.jar --erase -n <chipName>      <mode>    <port>    <xmlPath>    [programmer]    ");
    Log.println("burntoolcli.jar --erase -n chipName  -m serial     COM0   -x  xmlPath  -p  programmerPath");
    Log.println("burntoolcli.jar --erase -n chipName  -m USBBootrom        -x  xmlPath  -p  programmerPath");
  }
  
  public void printEarseBoot() {
    printEarseBootEg();
    printModeOptions();
    printPortOption();
    printProgrammerOption();
  }
  
  public UnknownDevice getDevice() {
    return this.device;
  }
  
  public void setDevice(UnknownDevice device) {
    this.device = device;
  }
  
  public String getChipName() {
    return this.chipName;
  }
  
  public void setChipName(String chipName) {
    this.chipName = chipName;
  }
  
  public TransferWay getMode() {
    return this.mode;
  }
  
  public void setMode(TransferWay mode) {
    this.mode = mode;
  }
  
  public String getPort() {
    return this.port;
  }
  
  public void setPort(String port) {
    this.port = port;
  }
  
  public FlashType getFlashType() {
    return this.flashType;
  }
  
  public void setFlashType(FlashType flashType) {
    this.flashType = flashType;
  }
  
  public File getBootFile() {
    return this.bootFile;
  }
  
  public void setBootFile(File bootFile) {
    this.bootFile = bootFile;
  }
  
  public File getProgrammer() {
    return this.programmer;
  }
  
  public void setProgrammer(File programmer) {
    this.programmer = programmer;
  }
  
  public List<String> getSerialPorts() {
    return this.serialPorts;
  }
  
  public void setSerialPorts(List<String> serialPorts) {
    this.serialPorts = serialPorts;
  }
  
  public List<PartitionItem> getPartitionList() {
    return this.partitionList;
  }
  
  public void setPartitionList(List<PartitionItem> partitionList) {
    this.partitionList = partitionList;
  }
  
  public String getXmlPath() {
    return this.xmlPath;
  }
  
  public void setXmlPath(String xmlPath) {
    this.xmlPath = xmlPath;
  }
}
